================================
``cavcalc.functions.asymmetric``
================================

.. automodule:: cavcalc.functions.asymmetric

.. currentmodule:: cavcalc.functions.asymmetric

Functions
=========

.. autosummary::
    :toctree: generated/

    w1_of_g1g2
	w2_of_g1g2
	w0_of_g1g2
	z0_of_g1g2
	rtgouy_of_g1g2
	g1_of_Rc1
	g2_of_Rc2
	g_of_Rc
	g_of_g1g2
	Rc1_of_g1
	Rc2_of_g2
	modesep_of_g1g2
	eigenmode_of_Rc1Rc2
